import { effectScope, ref, getCurrentScope, onScopeDispose, watch, getCurrentInstance, onMounted, nextTick, shallowRef, unref, reactive, computed, isRef, watchEffect, readonly, defineComponent, useSlots, openBlock, createElementBlock, mergeProps, renderSlot, normalizeClass, normalizeStyle, createCommentVNode, Fragment, createElementVNode, createTextVNode, createVNode, createBlock, withCtx, createSlots } from "vue";
var __uno = "";
function set(target, key, val) {
  if (Array.isArray(target)) {
    target.length = Math.max(target.length, key);
    target.splice(key, 1, val);
    return val;
  }
  target[key] = val;
  return val;
}
var _a;
const isClient = typeof window !== "undefined";
const isString$1 = (val) => typeof val === "string";
const noop = () => {
};
isClient && ((_a = window == null ? void 0 : window.navigator) == null ? void 0 : _a.userAgent) && /iP(ad|hone|od)/.test(window.navigator.userAgent);
function createFilterWrapper(filter2, fn) {
  function wrapper(...args) {
    filter2(() => fn.apply(this, args), { fn, thisArg: this, args });
  }
  return wrapper;
}
const bypassFilter = (invoke) => {
  return invoke();
};
function pausableFilter(extendFilter = bypassFilter) {
  const isActive = ref(true);
  function pause() {
    isActive.value = false;
  }
  function resume() {
    isActive.value = true;
  }
  const eventFilter = (...args) => {
    if (isActive.value)
      extendFilter(...args);
  };
  return { isActive, pause, resume, eventFilter };
}
function createGlobalState(stateFactory) {
  let initialized = false;
  let state;
  const scope = effectScope(true);
  return () => {
    if (!initialized) {
      state = scope.run(stateFactory);
      initialized = true;
    }
    return state;
  };
}
function tryOnScopeDispose(fn) {
  if (getCurrentScope()) {
    onScopeDispose(fn);
    return true;
  }
  return false;
}
function tryOnMounted(fn, sync = true) {
  if (getCurrentInstance())
    onMounted(fn);
  else if (sync)
    fn();
  else
    nextTick(fn);
}
var __getOwnPropSymbols$6 = Object.getOwnPropertySymbols;
var __hasOwnProp$6 = Object.prototype.hasOwnProperty;
var __propIsEnum$6 = Object.prototype.propertyIsEnumerable;
var __objRest$5 = (source, exclude) => {
  var target = {};
  for (var prop in source)
    if (__hasOwnProp$6.call(source, prop) && exclude.indexOf(prop) < 0)
      target[prop] = source[prop];
  if (source != null && __getOwnPropSymbols$6)
    for (var prop of __getOwnPropSymbols$6(source)) {
      if (exclude.indexOf(prop) < 0 && __propIsEnum$6.call(source, prop))
        target[prop] = source[prop];
    }
  return target;
};
function watchWithFilter(source, cb2, options = {}) {
  const _a2 = options, {
    eventFilter = bypassFilter
  } = _a2, watchOptions = __objRest$5(_a2, [
    "eventFilter"
  ]);
  return watch(source, createFilterWrapper(eventFilter, cb2), watchOptions);
}
var __defProp$2 = Object.defineProperty;
var __defProps$2 = Object.defineProperties;
var __getOwnPropDescs$2 = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols$2 = Object.getOwnPropertySymbols;
var __hasOwnProp$2 = Object.prototype.hasOwnProperty;
var __propIsEnum$2 = Object.prototype.propertyIsEnumerable;
var __defNormalProp$2 = (obj, key, value) => key in obj ? __defProp$2(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues$2 = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp$2.call(b, prop))
      __defNormalProp$2(a, prop, b[prop]);
  if (__getOwnPropSymbols$2)
    for (var prop of __getOwnPropSymbols$2(b)) {
      if (__propIsEnum$2.call(b, prop))
        __defNormalProp$2(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps$2 = (a, b) => __defProps$2(a, __getOwnPropDescs$2(b));
var __objRest$1 = (source, exclude) => {
  var target = {};
  for (var prop in source)
    if (__hasOwnProp$2.call(source, prop) && exclude.indexOf(prop) < 0)
      target[prop] = source[prop];
  if (source != null && __getOwnPropSymbols$2)
    for (var prop of __getOwnPropSymbols$2(source)) {
      if (exclude.indexOf(prop) < 0 && __propIsEnum$2.call(source, prop))
        target[prop] = source[prop];
    }
  return target;
};
function watchPausable(source, cb2, options = {}) {
  const _a2 = options, {
    eventFilter: filter2
  } = _a2, watchOptions = __objRest$1(_a2, [
    "eventFilter"
  ]);
  const { eventFilter, pause, resume, isActive } = pausableFilter(filter2);
  const stop = watchWithFilter(source, cb2, __spreadProps$2(__spreadValues$2({}, watchOptions), {
    eventFilter
  }));
  return { stop, pause, resume, isActive };
}
function computedAsync(evaluationCallback, initialState, optionsOrRef) {
  let options;
  if (isRef(optionsOrRef)) {
    options = {
      evaluating: optionsOrRef
    };
  } else {
    options = optionsOrRef || {};
  }
  const {
    lazy = false,
    evaluating = void 0,
    onError = noop
  } = options;
  const started = ref(!lazy);
  const current = ref(initialState);
  let counter = 0;
  watchEffect(async (onInvalidate) => {
    if (!started.value)
      return;
    counter++;
    const counterAtBeginning = counter;
    let hasFinished = false;
    if (evaluating) {
      Promise.resolve().then(() => {
        evaluating.value = true;
      });
    }
    try {
      const result = await evaluationCallback((cancelCallback) => {
        onInvalidate(() => {
          if (evaluating)
            evaluating.value = false;
          if (!hasFinished)
            cancelCallback();
        });
      });
      if (counterAtBeginning === counter)
        current.value = result;
    } catch (e) {
      onError(e);
    } finally {
      if (evaluating && counterAtBeginning === counter)
        evaluating.value = false;
      hasFinished = true;
    }
  });
  if (lazy) {
    return computed(() => {
      started.value = true;
      return current.value;
    });
  } else {
    return current;
  }
}
function unrefElement(elRef) {
  var _a2;
  const plain = unref(elRef);
  return (_a2 = plain == null ? void 0 : plain.$el) != null ? _a2 : plain;
}
const defaultWindow = isClient ? window : void 0;
function useEventListener(...args) {
  let target;
  let event;
  let listener;
  let options;
  if (isString$1(args[0])) {
    [event, listener, options] = args;
    target = defaultWindow;
  } else {
    [target, event, listener, options] = args;
  }
  if (!target)
    return noop;
  let cleanup = noop;
  const stopWatch = watch(() => unrefElement(target), (el) => {
    cleanup();
    if (!el)
      return;
    el.addEventListener(event, listener, options);
    cleanup = () => {
      el.removeEventListener(event, listener, options);
      cleanup = noop;
    };
  }, { immediate: true, flush: "post" });
  const stop = () => {
    stopWatch();
    cleanup();
  };
  tryOnScopeDispose(stop);
  return stop;
}
const _global = typeof globalThis !== "undefined" ? globalThis : typeof window !== "undefined" ? window : typeof global !== "undefined" ? global : typeof self !== "undefined" ? self : {};
const globalKey = "__vueuse_ssr_handlers__";
_global[globalKey] = _global[globalKey] || {};
const handlers = _global[globalKey];
function getSSRHandler(key, fallback) {
  return handlers[key] || fallback;
}
function guessSerializerType(rawInit) {
  return rawInit == null ? "any" : rawInit instanceof Set ? "set" : rawInit instanceof Map ? "map" : rawInit instanceof Date ? "date" : typeof rawInit === "boolean" ? "boolean" : typeof rawInit === "string" ? "string" : typeof rawInit === "object" ? "object" : Array.isArray(rawInit) ? "object" : !Number.isNaN(rawInit) ? "number" : "any";
}
const StorageSerializers = {
  boolean: {
    read: (v) => v === "true",
    write: (v) => String(v)
  },
  object: {
    read: (v) => JSON.parse(v),
    write: (v) => JSON.stringify(v)
  },
  number: {
    read: (v) => Number.parseFloat(v),
    write: (v) => String(v)
  },
  any: {
    read: (v) => v,
    write: (v) => String(v)
  },
  string: {
    read: (v) => v,
    write: (v) => String(v)
  },
  map: {
    read: (v) => new Map(JSON.parse(v)),
    write: (v) => JSON.stringify(Array.from(v.entries()))
  },
  set: {
    read: (v) => new Set(JSON.parse(v)),
    write: (v) => JSON.stringify(Array.from(v))
  },
  date: {
    read: (v) => new Date(v),
    write: (v) => v.toISOString()
  }
};
function useStorage(key, initialValue, storage, options = {}) {
  var _a2;
  const {
    flush = "pre",
    deep = true,
    listenToStorageChanges = true,
    writeDefaults = true,
    shallow,
    window: window2 = defaultWindow,
    eventFilter,
    onError = (e) => {
      console.error(e);
    }
  } = options;
  const data = (shallow ? shallowRef : ref)(initialValue);
  if (!storage) {
    try {
      storage = getSSRHandler("getDefaultStorage", () => {
        var _a22;
        return (_a22 = defaultWindow) == null ? void 0 : _a22.localStorage;
      })();
    } catch (e) {
      onError(e);
    }
  }
  if (!storage)
    return data;
  const rawInit = unref(initialValue);
  const type = guessSerializerType(rawInit);
  const serializer = (_a2 = options.serializer) != null ? _a2 : StorageSerializers[type];
  const { pause: pauseWatch, resume: resumeWatch } = watchPausable(data, () => write(data.value), { flush, deep, eventFilter });
  if (window2 && listenToStorageChanges)
    useEventListener(window2, "storage", update);
  update();
  return data;
  function write(v) {
    try {
      if (v == null)
        storage.removeItem(key);
      else
        storage.setItem(key, serializer.write(v));
    } catch (e) {
      onError(e);
    }
  }
  function read(event) {
    if (event && event.key !== key)
      return;
    pauseWatch();
    try {
      const rawValue = event ? event.newValue : storage.getItem(key);
      if (rawValue == null) {
        if (writeDefaults && rawInit !== null)
          storage.setItem(key, serializer.write(rawInit));
        return rawInit;
      } else if (typeof rawValue !== "string") {
        return rawValue;
      } else {
        return serializer.read(rawValue);
      }
    } catch (e) {
      onError(e);
    } finally {
      resumeWatch();
    }
  }
  function update(event) {
    if (event && event.key !== key)
      return;
    data.value = read(event);
  }
}
var __getOwnPropSymbols$e = Object.getOwnPropertySymbols;
var __hasOwnProp$e = Object.prototype.hasOwnProperty;
var __propIsEnum$e = Object.prototype.propertyIsEnumerable;
var __objRest$2 = (source, exclude) => {
  var target = {};
  for (var prop in source)
    if (__hasOwnProp$e.call(source, prop) && exclude.indexOf(prop) < 0)
      target[prop] = source[prop];
  if (source != null && __getOwnPropSymbols$e)
    for (var prop of __getOwnPropSymbols$e(source)) {
      if (exclude.indexOf(prop) < 0 && __propIsEnum$e.call(source, prop))
        target[prop] = source[prop];
    }
  return target;
};
function useResizeObserver(target, callback, options = {}) {
  const _a2 = options, { window: window2 = defaultWindow } = _a2, observerOptions = __objRest$2(_a2, ["window"]);
  let observer;
  const isSupported = window2 && "ResizeObserver" in window2;
  const cleanup = () => {
    if (observer) {
      observer.disconnect();
      observer = void 0;
    }
  };
  const stopWatch = watch(() => unrefElement(target), (el) => {
    cleanup();
    if (isSupported && window2 && el) {
      observer = new ResizeObserver(callback);
      observer.observe(el, observerOptions);
    }
  }, { immediate: true, flush: "post" });
  const stop = () => {
    cleanup();
    stopWatch();
  };
  tryOnScopeDispose(stop);
  return {
    isSupported,
    stop
  };
}
function useElementBounding(target, options = {}) {
  const {
    reset = true,
    windowResize = true,
    windowScroll = true,
    immediate = true
  } = options;
  const height = ref(0);
  const bottom = ref(0);
  const left = ref(0);
  const right = ref(0);
  const top = ref(0);
  const width = ref(0);
  const x = ref(0);
  const y = ref(0);
  function update() {
    const el = unrefElement(target);
    if (!el) {
      if (reset) {
        height.value = 0;
        bottom.value = 0;
        left.value = 0;
        right.value = 0;
        top.value = 0;
        width.value = 0;
        x.value = 0;
        y.value = 0;
      }
      return;
    }
    const rect = el.getBoundingClientRect();
    height.value = rect.height;
    bottom.value = rect.bottom;
    left.value = rect.left;
    right.value = rect.right;
    top.value = rect.top;
    width.value = rect.width;
    x.value = rect.x;
    y.value = rect.y;
  }
  useResizeObserver(target, update);
  watch(() => unrefElement(target), (ele) => !ele && update());
  if (windowScroll)
    useEventListener("scroll", update, { passive: true });
  if (windowResize)
    useEventListener("resize", update, { passive: true });
  tryOnMounted(() => {
    if (immediate)
      update();
  });
  return {
    height,
    bottom,
    left,
    right,
    top,
    width,
    x,
    y,
    update
  };
}
const DefaultMagicKeysAliasMap = {
  ctrl: "control",
  command: "meta",
  cmd: "meta",
  option: "alt",
  up: "arrowup",
  down: "arrowdown",
  left: "arrowleft",
  right: "arrowright"
};
function useMagicKeys(options = {}) {
  const {
    reactive: useReactive = false,
    target = defaultWindow,
    aliasMap = DefaultMagicKeysAliasMap,
    passive = true,
    onEventFired = noop
  } = options;
  const current = reactive(/* @__PURE__ */ new Set());
  const obj = { toJSON() {
    return {};
  }, current };
  const refs = useReactive ? reactive(obj) : obj;
  const metaDeps = /* @__PURE__ */ new Set();
  const usedKeys = /* @__PURE__ */ new Set();
  function setRefs(key, value) {
    if (key in refs) {
      if (useReactive)
        refs[key] = value;
      else
        refs[key].value = value;
    }
  }
  function reset() {
    for (const key of usedKeys)
      setRefs(key, false);
  }
  function updateRefs(e, value) {
    var _a2, _b;
    const key = (_a2 = e.key) == null ? void 0 : _a2.toLowerCase();
    const code = (_b = e.code) == null ? void 0 : _b.toLowerCase();
    const values = [code, key].filter(Boolean);
    if (code) {
      if (value)
        current.add(e.code);
      else
        current.delete(e.code);
    }
    for (const key2 of values) {
      usedKeys.add(key2);
      setRefs(key2, value);
    }
    if (key === "meta" && !value) {
      metaDeps.forEach((key2) => {
        current.delete(key2);
        setRefs(key2, false);
      });
      metaDeps.clear();
    } else if (typeof e.getModifierState === "function" && e.getModifierState("Meta") && value) {
      [...current, ...values].forEach((key2) => metaDeps.add(key2));
    }
  }
  if (target) {
    useEventListener(target, "keydown", (e) => {
      updateRefs(e, true);
      return onEventFired(e);
    }, { passive });
    useEventListener(target, "keyup", (e) => {
      updateRefs(e, false);
      return onEventFired(e);
    }, { passive });
    useEventListener("blur", reset, { passive: true });
    useEventListener("focus", reset, { passive: true });
  }
  const proxy = new Proxy(refs, {
    get(target2, prop, rec) {
      if (typeof prop !== "string")
        return Reflect.get(target2, prop, rec);
      prop = prop.toLowerCase();
      if (prop in aliasMap)
        prop = aliasMap[prop];
      if (!(prop in refs)) {
        if (/[+_-]/.test(prop)) {
          const keys = prop.split(/[+_-]/g).map((i) => i.trim());
          refs[prop] = computed(() => keys.every((key) => unref(proxy[key])));
        } else {
          refs[prop] = ref(false);
        }
      }
      const r = Reflect.get(target2, prop, rec);
      return useReactive ? unref(r) : r;
    }
  });
  return proxy;
}
var SwipeDirection;
(function(SwipeDirection2) {
  SwipeDirection2["UP"] = "UP";
  SwipeDirection2["RIGHT"] = "RIGHT";
  SwipeDirection2["DOWN"] = "DOWN";
  SwipeDirection2["LEFT"] = "LEFT";
  SwipeDirection2["NONE"] = "NONE";
})(SwipeDirection || (SwipeDirection = {}));
function usePointerSwipe(target, options = {}) {
  const targetRef = ref(target);
  const {
    threshold = 50,
    onSwipe,
    onSwipeEnd,
    onSwipeStart
  } = options;
  const posStart = reactive({ x: 0, y: 0 });
  const updatePosStart = (x, y) => {
    posStart.x = x;
    posStart.y = y;
  };
  const posEnd = reactive({ x: 0, y: 0 });
  const updatePosEnd = (x, y) => {
    posEnd.x = x;
    posEnd.y = y;
  };
  const distanceX = computed(() => posStart.x - posEnd.x);
  const distanceY = computed(() => posStart.y - posEnd.y);
  const { max, abs } = Math;
  const isThresholdExceeded = computed(() => max(abs(distanceX.value), abs(distanceY.value)) >= threshold);
  const isSwiping = ref(false);
  const isPointerDown = ref(false);
  const direction = computed(() => {
    if (!isThresholdExceeded.value)
      return SwipeDirection.NONE;
    if (abs(distanceX.value) > abs(distanceY.value)) {
      return distanceX.value > 0 ? SwipeDirection.LEFT : SwipeDirection.RIGHT;
    } else {
      return distanceY.value > 0 ? SwipeDirection.UP : SwipeDirection.DOWN;
    }
  });
  const filterEvent = (e) => {
    if (options.pointerTypes)
      return options.pointerTypes.includes(e.pointerType);
    return true;
  };
  const stops = [
    useEventListener(target, "pointerdown", (e) => {
      var _a2, _b;
      if (!filterEvent(e))
        return;
      isPointerDown.value = true;
      (_b = (_a2 = targetRef.value) == null ? void 0 : _a2.style) == null ? void 0 : _b.setProperty("touch-action", "none");
      const eventTarget = e.target;
      eventTarget == null ? void 0 : eventTarget.setPointerCapture(e.pointerId);
      const { clientX: x, clientY: y } = e;
      updatePosStart(x, y);
      updatePosEnd(x, y);
      onSwipeStart == null ? void 0 : onSwipeStart(e);
    }),
    useEventListener(target, "pointermove", (e) => {
      if (!filterEvent(e))
        return;
      if (!isPointerDown.value)
        return;
      const { clientX: x, clientY: y } = e;
      updatePosEnd(x, y);
      if (!isSwiping.value && isThresholdExceeded.value)
        isSwiping.value = true;
      if (isSwiping.value)
        onSwipe == null ? void 0 : onSwipe(e);
    }),
    useEventListener(target, "pointerup", (e) => {
      var _a2, _b;
      if (!filterEvent(e))
        return;
      if (isSwiping.value)
        onSwipeEnd == null ? void 0 : onSwipeEnd(e, direction.value);
      isPointerDown.value = false;
      isSwiping.value = false;
      (_b = (_a2 = targetRef.value) == null ? void 0 : _a2.style) == null ? void 0 : _b.setProperty("touch-action", "initial");
    })
  ];
  const stop = () => stops.forEach((s) => s());
  return {
    isSwiping: readonly(isSwiping),
    direction: readonly(direction),
    posStart: readonly(posStart),
    posEnd: readonly(posEnd),
    distanceX,
    distanceY,
    stop
  };
}
function useWindowSize(options = {}) {
  const {
    window: window2 = defaultWindow,
    initialWidth = Infinity,
    initialHeight = Infinity,
    listenOrientation = true
  } = options;
  const width = ref(initialWidth);
  const height = ref(initialHeight);
  const update = () => {
    if (window2) {
      width.value = window2.innerWidth;
      height.value = window2.innerHeight;
    }
  };
  update();
  tryOnMounted(update);
  useEventListener("resize", update, { passive: true });
  if (listenOrientation)
    useEventListener("orientationchange", update, { passive: true });
  return { width, height };
}
const defaultTimestep = 1 / 60 * 1e3;
const getCurrentTime = typeof performance !== "undefined" ? () => performance.now() : () => Date.now();
const onNextFrame = typeof window !== "undefined" ? (callback) => window.requestAnimationFrame(callback) : (callback) => setTimeout(() => callback(getCurrentTime()), defaultTimestep);
function createRenderStep(runNextFrame2) {
  let toRun = [];
  let toRunNextFrame = [];
  let numToRun = 0;
  let isProcessing2 = false;
  let flushNextFrame = false;
  const toKeepAlive = /* @__PURE__ */ new WeakSet();
  const step = {
    schedule: (callback, keepAlive = false, immediate = false) => {
      const addToCurrentFrame = immediate && isProcessing2;
      const buffer = addToCurrentFrame ? toRun : toRunNextFrame;
      if (keepAlive)
        toKeepAlive.add(callback);
      if (buffer.indexOf(callback) === -1) {
        buffer.push(callback);
        if (addToCurrentFrame && isProcessing2)
          numToRun = toRun.length;
      }
      return callback;
    },
    cancel: (callback) => {
      const index = toRunNextFrame.indexOf(callback);
      if (index !== -1)
        toRunNextFrame.splice(index, 1);
      toKeepAlive.delete(callback);
    },
    process: (frameData) => {
      if (isProcessing2) {
        flushNextFrame = true;
        return;
      }
      isProcessing2 = true;
      [toRun, toRunNextFrame] = [toRunNextFrame, toRun];
      toRunNextFrame.length = 0;
      numToRun = toRun.length;
      if (numToRun) {
        for (let i = 0; i < numToRun; i++) {
          const callback = toRun[i];
          callback(frameData);
          if (toKeepAlive.has(callback)) {
            step.schedule(callback);
            runNextFrame2();
          }
        }
      }
      isProcessing2 = false;
      if (flushNextFrame) {
        flushNextFrame = false;
        step.process(frameData);
      }
    }
  };
  return step;
}
const maxElapsed = 40;
let useDefaultElapsed = true;
let runNextFrame = false;
let isProcessing = false;
const frame = {
  delta: 0,
  timestamp: 0
};
const stepsOrder = [
  "read",
  "update",
  "preRender",
  "render",
  "postRender"
];
const steps = stepsOrder.reduce((acc, key) => {
  acc[key] = createRenderStep(() => runNextFrame = true);
  return acc;
}, {});
stepsOrder.reduce((acc, key) => {
  const step = steps[key];
  acc[key] = (process, keepAlive = false, immediate = false) => {
    if (!runNextFrame)
      startLoop();
    return step.schedule(process, keepAlive, immediate);
  };
  return acc;
}, {});
stepsOrder.reduce((acc, key) => {
  acc[key] = steps[key].cancel;
  return acc;
}, {});
stepsOrder.reduce((acc, key) => {
  acc[key] = () => steps[key].process(frame);
  return acc;
}, {});
const processStep = (stepId) => steps[stepId].process(frame);
const processFrame = (timestamp) => {
  runNextFrame = false;
  frame.delta = useDefaultElapsed ? defaultTimestep : Math.max(Math.min(timestamp - frame.timestamp, maxElapsed), 1);
  frame.timestamp = timestamp;
  isProcessing = true;
  stepsOrder.forEach(processStep);
  isProcessing = false;
  if (runNextFrame) {
    useDefaultElapsed = false;
    onNextFrame(processFrame);
  }
};
const startLoop = () => {
  runNextFrame = true;
  useDefaultElapsed = true;
  if (!isProcessing)
    onNextFrame(processFrame);
};
const clamp = (min, max) => (v) => Math.max(Math.min(v, max), min);
const sanitize = (v) => v % 1 ? Number(v.toFixed(5)) : v;
const floatRegex = /(-)?([\d]*\.?[\d])+/g;
const colorRegex = /(#[0-9a-f]{6}|#[0-9a-f]{3}|#(?:[0-9a-f]{2}){2,4}|(rgb|hsl)a?\((-?[\d\.]+%?[,\s]+){2}(-?[\d\.]+%?)\s*[\,\/]?\s*[\d\.]*%?\))/gi;
const singleColorRegex = /^(#[0-9a-f]{3}|#(?:[0-9a-f]{2}){2,4}|(rgb|hsl)a?\((-?[\d\.]+%?[,\s]+){2}(-?[\d\.]+%?)\s*[\,\/]?\s*[\d\.]*%?\))$/i;
function isString(v) {
  return typeof v === "string";
}
const number = {
  test: (v) => typeof v === "number",
  parse: parseFloat,
  transform: (v) => v
};
const alpha = Object.assign(Object.assign({}, number), { transform: clamp(0, 1) });
const scale = Object.assign(Object.assign({}, number), { default: 1 });
const createUnitType = (unit) => ({
  test: (v) => isString(v) && v.endsWith(unit) && v.split(" ").length === 1,
  parse: parseFloat,
  transform: (v) => `${v}${unit}`
});
const degrees = createUnitType("deg");
const percent = createUnitType("%");
const px = createUnitType("px");
const progressPercentage = Object.assign(Object.assign({}, percent), { parse: (v) => percent.parse(v) / 100, transform: (v) => percent.transform(v * 100) });
const isColorString = (type, testProp) => (v) => {
  return Boolean(isString(v) && singleColorRegex.test(v) && v.startsWith(type) || testProp && Object.prototype.hasOwnProperty.call(v, testProp));
};
const splitColor = (aName, bName, cName) => (v) => {
  if (!isString(v))
    return v;
  const [a, b, c, alpha2] = v.match(floatRegex);
  return {
    [aName]: parseFloat(a),
    [bName]: parseFloat(b),
    [cName]: parseFloat(c),
    alpha: alpha2 !== void 0 ? parseFloat(alpha2) : 1
  };
};
const hsla = {
  test: isColorString("hsl", "hue"),
  parse: splitColor("hue", "saturation", "lightness"),
  transform: ({ hue, saturation, lightness, alpha: alpha$1 = 1 }) => {
    return "hsla(" + Math.round(hue) + ", " + percent.transform(sanitize(saturation)) + ", " + percent.transform(sanitize(lightness)) + ", " + sanitize(alpha.transform(alpha$1)) + ")";
  }
};
const clampRgbUnit = clamp(0, 255);
const rgbUnit = Object.assign(Object.assign({}, number), { transform: (v) => Math.round(clampRgbUnit(v)) });
const rgba = {
  test: isColorString("rgb", "red"),
  parse: splitColor("red", "green", "blue"),
  transform: ({ red, green, blue, alpha: alpha$1 = 1 }) => "rgba(" + rgbUnit.transform(red) + ", " + rgbUnit.transform(green) + ", " + rgbUnit.transform(blue) + ", " + sanitize(alpha.transform(alpha$1)) + ")"
};
function parseHex(v) {
  let r = "";
  let g = "";
  let b = "";
  let a = "";
  if (v.length > 5) {
    r = v.substr(1, 2);
    g = v.substr(3, 2);
    b = v.substr(5, 2);
    a = v.substr(7, 2);
  } else {
    r = v.substr(1, 1);
    g = v.substr(2, 1);
    b = v.substr(3, 1);
    a = v.substr(4, 1);
    r += r;
    g += g;
    b += b;
    a += a;
  }
  return {
    red: parseInt(r, 16),
    green: parseInt(g, 16),
    blue: parseInt(b, 16),
    alpha: a ? parseInt(a, 16) / 255 : 1
  };
}
const hex = {
  test: isColorString("#"),
  parse: parseHex,
  transform: rgba.transform
};
const color = {
  test: (v) => rgba.test(v) || hex.test(v) || hsla.test(v),
  parse: (v) => {
    if (rgba.test(v)) {
      return rgba.parse(v);
    } else if (hsla.test(v)) {
      return hsla.parse(v);
    } else {
      return hex.parse(v);
    }
  },
  transform: (v) => {
    return isString(v) ? v : v.hasOwnProperty("red") ? rgba.transform(v) : hsla.transform(v);
  }
};
const colorToken = "${c}";
const numberToken = "${n}";
function test(v) {
  var _a2, _b, _c, _d;
  return isNaN(v) && isString(v) && ((_b = (_a2 = v.match(floatRegex)) === null || _a2 === void 0 ? void 0 : _a2.length) !== null && _b !== void 0 ? _b : 0) + ((_d = (_c = v.match(colorRegex)) === null || _c === void 0 ? void 0 : _c.length) !== null && _d !== void 0 ? _d : 0) > 0;
}
function analyse(v) {
  if (typeof v === "number")
    v = `${v}`;
  const values = [];
  let numColors = 0;
  const colors = v.match(colorRegex);
  if (colors) {
    numColors = colors.length;
    v = v.replace(colorRegex, colorToken);
    values.push(...colors.map(color.parse));
  }
  const numbers = v.match(floatRegex);
  if (numbers) {
    v = v.replace(floatRegex, numberToken);
    values.push(...numbers.map(number.parse));
  }
  return { values, numColors, tokenised: v };
}
function parse(v) {
  return analyse(v).values;
}
function createTransformer(v) {
  const { values, numColors, tokenised } = analyse(v);
  const numValues = values.length;
  return (v2) => {
    let output = tokenised;
    for (let i = 0; i < numValues; i++) {
      output = output.replace(i < numColors ? colorToken : numberToken, i < numColors ? color.transform(v2[i]) : sanitize(v2[i]));
    }
    return output;
  };
}
const convertNumbersToZero = (v) => typeof v === "number" ? 0 : v;
function getAnimatableNone(v) {
  const parsed = parse(v);
  const transformer = createTransformer(v);
  return transformer(parsed.map(convertNumbersToZero));
}
const complex = { test, parse, createTransformer, getAnimatableNone };
const maxDefaults = /* @__PURE__ */ new Set(["brightness", "contrast", "saturate", "opacity"]);
function applyDefaultFilter(v) {
  let [name, value] = v.slice(0, -1).split("(");
  if (name === "drop-shadow")
    return v;
  const [number2] = value.match(floatRegex) || [];
  if (!number2)
    return v;
  const unit = value.replace(number2, "");
  let defaultValue = maxDefaults.has(name) ? 1 : 0;
  if (number2 !== value)
    defaultValue *= 100;
  return name + "(" + defaultValue + unit + ")";
}
const functionRegex = /([a-z-]*)\(.*?\)/g;
const filter = Object.assign(Object.assign({}, complex), { getAnimatableNone: (v) => {
  const functions = v.match(functionRegex);
  return functions ? functions.map(applyDefaultFilter).join(" ") : v;
} });
const reverseEasing = (easing) => (p) => 1 - easing(1 - p);
const mirrorEasing = (easing) => (p) => p <= 0.5 ? easing(2 * p) / 2 : (2 - easing(2 * (1 - p))) / 2;
const createExpoIn = (power) => (p) => Math.pow(p, power);
const createBackIn = (power) => (p) => p * p * ((power + 1) * p - power);
const createAnticipate = (power) => {
  const backEasing = createBackIn(power);
  return (p) => (p *= 2) < 1 ? 0.5 * backEasing(p) : 0.5 * (2 - Math.pow(2, -10 * (p - 1)));
};
const DEFAULT_OVERSHOOT_STRENGTH = 1.525;
const BOUNCE_FIRST_THRESHOLD = 4 / 11;
const BOUNCE_SECOND_THRESHOLD = 8 / 11;
const BOUNCE_THIRD_THRESHOLD = 9 / 10;
const linear = (p) => p;
const easeIn = createExpoIn(2);
const easeOut = reverseEasing(easeIn);
const easeInOut = mirrorEasing(easeIn);
const circIn = (p) => 1 - Math.sin(Math.acos(p));
const circOut = reverseEasing(circIn);
const circInOut = mirrorEasing(circOut);
const backIn = createBackIn(DEFAULT_OVERSHOOT_STRENGTH);
const backOut = reverseEasing(backIn);
const backInOut = mirrorEasing(backIn);
const anticipate = createAnticipate(DEFAULT_OVERSHOOT_STRENGTH);
const ca = 4356 / 361;
const cb = 35442 / 1805;
const cc = 16061 / 1805;
const bounceOut = (p) => {
  if (p === 1 || p === 0)
    return p;
  const p2 = p * p;
  return p < BOUNCE_FIRST_THRESHOLD ? 7.5625 * p2 : p < BOUNCE_SECOND_THRESHOLD ? 9.075 * p2 - 9.9 * p + 3.4 : p < BOUNCE_THIRD_THRESHOLD ? ca * p2 - cb * p + cc : 10.8 * p * p - 20.52 * p + 10.72;
};
const bounceIn = reverseEasing(bounceOut);
const bounceInOut = (p) => p < 0.5 ? 0.5 * (1 - bounceOut(1 - p * 2)) : 0.5 * bounceOut(p * 2 - 1) + 0.5;
const int = {
  ...number,
  transform: Math.round
};
const valueTypes = {
  color,
  backgroundColor: color,
  outlineColor: color,
  fill: color,
  stroke: color,
  borderColor: color,
  borderTopColor: color,
  borderRightColor: color,
  borderBottomColor: color,
  borderLeftColor: color,
  borderWidth: px,
  borderTopWidth: px,
  borderRightWidth: px,
  borderBottomWidth: px,
  borderLeftWidth: px,
  borderRadius: px,
  radius: px,
  borderTopLeftRadius: px,
  borderTopRightRadius: px,
  borderBottomRightRadius: px,
  borderBottomLeftRadius: px,
  width: px,
  maxWidth: px,
  height: px,
  maxHeight: px,
  size: px,
  top: px,
  right: px,
  bottom: px,
  left: px,
  padding: px,
  paddingTop: px,
  paddingRight: px,
  paddingBottom: px,
  paddingLeft: px,
  margin: px,
  marginTop: px,
  marginRight: px,
  marginBottom: px,
  marginLeft: px,
  rotate: degrees,
  rotateX: degrees,
  rotateY: degrees,
  rotateZ: degrees,
  scale,
  scaleX: scale,
  scaleY: scale,
  scaleZ: scale,
  skew: degrees,
  skewX: degrees,
  skewY: degrees,
  distance: px,
  translateX: px,
  translateY: px,
  translateZ: px,
  x: px,
  y: px,
  z: px,
  perspective: px,
  transformPerspective: px,
  opacity: alpha,
  originX: progressPercentage,
  originY: progressPercentage,
  originZ: px,
  zIndex: int,
  filter,
  WebkitFilter: filter,
  fillOpacity: alpha,
  strokeOpacity: alpha,
  numOctaves: int
};
const getValueType = (key) => valueTypes[key];
const getValueAsType = (value, type) => {
  return type && typeof value === "number" && type.transform ? type.transform(value) : value;
};
({
  linear,
  easeIn,
  easeInOut,
  easeOut,
  circIn,
  circInOut,
  circOut,
  backIn,
  backInOut,
  backOut,
  anticipate,
  bounceIn,
  bounceInOut,
  bounceOut
});
function reactiveStyle(props = {}) {
  const state = reactive({
    ...props
  });
  const style = ref({});
  watch(state, () => {
    const result = {};
    for (const [key, value] of Object.entries(state)) {
      const valueType = getValueType(key);
      const valueAsType = getValueAsType(value, valueType);
      result[key] = valueAsType;
    }
    style.value = result;
  }, {
    immediate: true,
    deep: true
  });
  return {
    state,
    style
  };
}
const transformAxes = ["", "X", "Y", "Z"];
const order = ["perspective", "translate", "scale", "rotate", "skew"];
const transformProps = ["transformPerspective", "x", "y", "z"];
order.forEach((operationKey) => {
  transformAxes.forEach((axesKey) => {
    const key = operationKey + axesKey;
    transformProps.push(key);
  });
});
const transformPropSet = new Set(transformProps);
function isTransformProp(key) {
  return transformPropSet.has(key);
}
const transformOriginProps = /* @__PURE__ */ new Set(["originX", "originY", "originZ"]);
function isTransformOriginProp(key) {
  return transformOriginProps.has(key);
}
function useElementStyle(target, onInit) {
  let _cache;
  let _target;
  const { state, style } = reactiveStyle();
  const stopInitWatch = watch(() => unrefElement(target), (el) => {
    if (!el)
      return;
    _target = el;
    for (const key of Object.keys(valueTypes)) {
      if (el.style[key] === null || el.style[key] === "" || isTransformProp(key) || isTransformOriginProp(key))
        continue;
      set(state, key, el.style[key]);
    }
    if (_cache) {
      Object.entries(_cache).forEach(([key, value]) => set(el.style, key, value));
    }
    if (onInit)
      onInit(state);
  }, {
    immediate: true
  });
  const stopSyncWatch = watch(style, (newVal) => {
    if (!_target) {
      _cache = newVal;
      return;
    }
    for (const key in newVal)
      set(_target.style, key, newVal[key]);
  }, {
    immediate: true
  });
  const stop = () => {
    _target = void 0;
    _cache = void 0;
    stopInitWatch();
    stopSyncWatch();
  };
  return {
    style: state,
    stop
  };
}
const translateAlias = {
  x: "translateX",
  y: "translateY",
  z: "translateZ"
};
function reactiveTransform(props = {}, enableHardwareAcceleration = true) {
  const state = reactive({ ...props });
  const transform = ref("");
  watch(state, (newVal) => {
    let result = "";
    let hasHardwareAcceleration = false;
    if (enableHardwareAcceleration && (newVal.x || newVal.y || newVal.z)) {
      const str = [newVal.x || 0, newVal.y || 0, newVal.z || 0].map(px.transform).join(",");
      result += `translate3d(${str}) `;
      hasHardwareAcceleration = true;
    }
    for (const [key, value] of Object.entries(newVal)) {
      if (enableHardwareAcceleration && (key === "x" || key === "y" || key === "z"))
        continue;
      const valueType = getValueType(key);
      const valueAsType = getValueAsType(value, valueType);
      result += `${translateAlias[key] || key}(${valueAsType}) `;
    }
    if (enableHardwareAcceleration && !hasHardwareAcceleration)
      result += "translateZ(0px) ";
    transform.value = result.trim();
  }, {
    immediate: true,
    deep: true
  });
  return {
    state,
    transform
  };
}
function parseTransform(transform) {
  const transforms = transform.trim().split(/\) |\)/);
  if (transforms.length === 1)
    return {};
  const parseValues = (value) => {
    if (value.endsWith("px") || value.endsWith("deg"))
      return parseFloat(value);
    if (isNaN(Number(value)))
      return Number(value);
    return value;
  };
  return transforms.reduce((acc, transform2) => {
    if (!transform2)
      return acc;
    const [name, transformValue] = transform2.split("(");
    const valueArray = transformValue.split(",");
    const values = valueArray.map((val) => {
      return parseValues(val.endsWith(")") ? val.replace(")", "") : val.trim());
    });
    const value = values.length === 1 ? values[0] : values;
    return {
      ...acc,
      [name]: value
    };
  }, {});
}
function stateFromTransform(state, transform) {
  Object.entries(parseTransform(transform)).forEach(([key, value]) => {
    value = parseFloat(value);
    const axes = ["x", "y", "z"];
    if (key === "translate3d") {
      if (value === 0) {
        axes.forEach((axis) => {
          set(state, axis, 0);
        });
        return;
      }
      value.forEach((axisValue, index) => {
        set(state, axes[index], axisValue);
      });
      return;
    }
    if (key === "translateX") {
      set(state, "x", value);
      return;
    }
    if (key === "translateY") {
      set(state, "y", value);
      return;
    }
    if (key === "translateZ") {
      set(state, "z", value);
      return;
    }
    set(state, key, value);
  });
}
function useElementTransform(target, onInit) {
  let _cache;
  let _target;
  const { state, transform } = reactiveTransform();
  const stopInitWatch = watch(() => unrefElement(target), (el) => {
    if (!el)
      return;
    _target = el;
    if (el.style.transform)
      stateFromTransform(state, el.style.transform);
    if (_cache)
      el.style.transform = _cache;
    if (onInit)
      onInit(state);
  }, {
    immediate: true
  });
  const stopSyncWatch = watch(transform, (newValue) => {
    if (!_target) {
      _cache = newValue;
      return;
    }
    _target.style.transform = newValue;
  }, {
    immediate: true
  });
  const stop = () => {
    _cache = void 0;
    _target = void 0;
    stopInitWatch();
    stopSyncWatch();
  };
  return {
    transform: state,
    stop
  };
}
function useMotionProperties(target, defaultValues) {
  const motionProperties = reactive({});
  const apply = (values) => {
    Object.entries(values).forEach(([key, value]) => {
      set(motionProperties, key, value);
    });
  };
  const { style, stop: stopStyleWatchers } = useElementStyle(target, apply);
  const { transform, stop: stopTransformWatchers } = useElementTransform(target, apply);
  const stopPropertiesWatch = watch(motionProperties, (newVal) => {
    Object.entries(newVal).forEach(([key, value]) => {
      const target2 = isTransformProp(key) ? transform : style;
      if (target2[key] && target2[key] === value)
        return;
      set(target2, key, value);
    });
  }, {
    immediate: true,
    deep: true
  });
  const stopInitWatch = watch(() => unrefElement(target), (el) => {
    if (!el)
      return;
    if (defaultValues)
      apply(defaultValues);
  }, {
    immediate: true
  });
  const stop = () => {
    stopStyleWatchers();
    stopTransformWatchers();
    stopPropertiesWatch();
    stopInitWatch();
  };
  return {
    motionProperties,
    style,
    transform,
    stop
  };
}
const useKeyShowHidden = (box) => {
  const keys = useMagicKeys();
  const keyState = keys[box.shortcutsKey];
  watch(keyState, (v) => {
    if (v)
      box.show = !box.show;
  });
};
const storeKeyRoot = "rose-layout-config";
const defaultConfig = {
  ZIndex: {
    up: 1999,
    down: -1
  },
  Bg: {
    color: "",
    bg: "",
    show: true,
    shortcutsKey: "ControlLeft+AltLeft+Backspace",
    zIndex: void 0,
    py: 0,
    px: 0,
    bgImg: "",
    bgVideo: "",
    bgImgOpacity: 0.1,
    bgFit: "cover"
  },
  Header: {
    color: "",
    bg: "",
    bgImg: "",
    bgVideo: "",
    bgImgOpacity: 0.1,
    bgFit: "cover",
    cardBg: "",
    show: true,
    showCard: true,
    width: 0,
    height: 0,
    isZero: true,
    boxShadow: "",
    shortcutsKey: "ControlLeft+AltLeft+ArrowUp",
    zIndex: 4,
    py: 0,
    px: 0
  },
  Footer: {
    color: "red",
    bg: "linear-gradient(to right, #4ac29a, #bdfff3)",
    cardBg: "",
    show: true,
    showCard: true,
    width: 0,
    height: 0,
    isZero: true,
    boxShadow: "",
    shortcutsKey: "ControlLeft+AltLeft+ArrowDown",
    zIndex: 4,
    py: 0,
    px: 0
  },
  Left: {
    color: "",
    bg: "#ffffff",
    bgImg: "",
    bgVideo: "",
    bgImgOpacity: 0.1,
    bgFit: "cover",
    cardBg: "",
    show: true,
    showCard: true,
    width: 0,
    height: 0,
    isZero: true,
    boxShadow: "",
    shortcutsKey: "ControlLeft+AltLeft+ArrowLeft",
    zIndex: 3,
    py: 0,
    px: 0
  },
  Right: {
    color: "",
    bg: "",
    bgImg: "",
    bgVideo: "",
    bgImgOpacity: 0.1,
    bgFit: "cover",
    cardBg: "",
    show: true,
    showCard: true,
    width: 0,
    height: 0,
    isZero: true,
    boxShadow: "",
    shortcutsKey: "ControlLeft+AltLeft+ArrowRight",
    zIndex: 3,
    py: 0,
    px: 0
  },
  Content: {
    color: "",
    bg: "",
    show: true,
    width: 0,
    height: 0,
    boxShadow: "",
    shortcutsKey: "ControlLeft+AltLeft+ControlRight",
    zIndex: 2,
    py: 0,
    px: 0,
    pt: 0,
    pb: 0,
    pl: 0,
    pr: 0,
    pointerEvents: false
  },
  ContentTop: {
    color: "",
    bg: "",
    show: true,
    width: 0,
    height: 0,
    boxShadow: "",
    shortcutsKey: "ShiftLeft+ArrowUp",
    zIndex: 2,
    py: 0,
    px: 0
  },
  ContentBox: {
    show: true,
    color: "",
    bg: "",
    boxShadow: "",
    shortcutsKey: "ShiftLeft+ArrowRight",
    zIndex: 1,
    py: 0,
    px: 0,
    pt: 0,
    pb: 0,
    pl: 0,
    pr: 0,
    overflow: true
  },
  ContentBottom: {
    color: "",
    bg: "",
    show: true,
    width: 0,
    height: 0,
    boxShadow: "",
    shortcutsKey: "ShiftLeft+ArrowDown",
    zIndex: 2,
    py: 0,
    px: 0
  },
  Setting: {
    show: true,
    shortcutsKey: "ControlLeft+AltLeft+Enter",
    zIndex: 1999
  }
};
const useKeyLayout = () => {
  return { [storeKeyRoot]: defaultConfig };
};
const useGlobalConfig = createGlobalState(() => useStorage(storeKeyRoot, defaultConfig));
const config = useGlobalConfig();
const useConfigLayout = (storeKey, newConfig) => {
  if (storeKey) {
    if (Object.keys(config.value).includes(storeKey)) {
      return config.value[storeKey];
    } else {
      return config;
    }
  } else {
    newConfig && (config.value = { ...newConfig });
    return config;
  }
};
const useKeyConfigLayout = () => {
  return { [storeKeyRoot]: config };
};
var _export_sfc = (sfc, props) => {
  const target = sfc.__vccOpts || sfc;
  for (const [key, val] of props) {
    target[key] = val;
  }
  return target;
};
const __default__$6 = {
  inheritAttrs: false
};
const _sfc_main$b = /* @__PURE__ */ defineComponent({
  ...__default__$6,
  __name: "RoseLayoutFooter",
  props: {
    cardHeight: { type: Number, required: false },
    cover: { type: Boolean, required: false, default: true },
    threshold: { type: Number, required: false, default: 15 },
    cardStyle: { type: null, required: false },
    cardClass: { type: [Array, Object], required: false }
  },
  setup(__props, { expose }) {
    const props = __props;
    const solts = useSlots();
    const showCard = computed(() => {
      return solts.card && config.value.Footer.showCard;
    });
    const { width, height } = useWindowSize();
    const footer = ref(null);
    const Rect = useElementBounding(footer);
    const card = ref(null);
    const { width: cardW, height: cardH } = useElementBounding(card);
    const { motionProperties: cardProp } = useMotionProperties(card);
    const cardIndex = config.value.ZIndex;
    const isZero = ref(true);
    cardProp.zIndex = cardIndex.down;
    cardProp.opacity = 0;
    cardProp.top = 0;
    cardProp.left = 0;
    cardProp.right = 0;
    cardProp.position = "absolute";
    cardProp.height = computedAsync(async () => {
      if (props.cardHeight) {
        return props.cardHeight;
      } else {
        return props.cover ? height.value : height.value - Rect.height.value;
      }
    }, null);
    const onZeroTRUE = () => {
      cardProp.zIndex = cardIndex.down;
      cardProp.opacity = 0;
      cardProp.y = 0;
    };
    const onZeroFALSE = () => {
      cardProp.zIndex = cardIndex.up;
      cardProp.opacity = 1;
      cardProp.y = props.cover ? -(cardH.value - Rect.height.value) : -cardH.value;
    };
    const { distanceY, isSwiping } = usePointerSwipe(footer, {
      threshold: props.threshold,
      onSwipeStart(e) {
        if (!showCard.value)
          return;
        isZero.value = cardProp.y ? false : true;
      },
      onSwipe(e) {
        if (!showCard.value)
          return;
        if (distanceY.value < 0) {
          if (!isZero.value) {
            cardProp.zIndex = cardIndex.up;
            cardProp.y = props.cover ? -(cardH.value - Rect.height.value) - distanceY.value : -cardH.value - distanceY.value;
            cardProp.opacity = 1.25 - distanceY.value / cardH.value;
          }
        } else {
          if (isZero.value) {
            cardProp.zIndex = cardIndex.up;
            cardProp.y = -distanceY.value;
            cardProp.opacity = Math.abs(distanceY.value) / cardH.value;
          }
        }
      },
      onSwipeEnd(e, direction) {
        if (!showCard.value)
          return;
        if (direction === "UP" && height.value && isZero.value && Math.abs(distanceY.value) / height.value >= 0.2) {
          isZero.value = false;
          onZeroFALSE();
        } else if (direction === "DOWN" && height.value && !isZero.value && Math.abs(distanceY.value) / height.value >= 0.2) {
          isZero.value = true;
          onZeroTRUE();
        } else {
          if (isZero.value) {
            onZeroTRUE();
          } else {
            onZeroFALSE();
          }
        }
      }
    });
    watch([Rect.width, Rect.height, isZero], ([newFooterW, newFooterH, newisZero]) => {
      config.value.Footer.width = newFooterW;
      config.value.Footer.height = newFooterH;
      config.value.Footer.isZero = newisZero;
    });
    const isShow = computed(() => config.value.Footer.show);
    const color2 = computed(() => config.value.Footer.color);
    const bg = computed(() => config.value.Footer.bg);
    const cardBg = computed(() => config.value.Footer.cardBg);
    const zIndex = config.value.Footer.zIndex;
    const boxShadow = computed(() => config.value.Footer.boxShadow);
    const py = computed(() => config.value.Footer.py);
    const px2 = computed(() => config.value.Footer.px);
    useKeyShowHidden(config.value.Footer);
    expose({
      cardReset: onZeroTRUE,
      cardOpen: onZeroFALSE
    });
    return (_ctx, _cache) => {
      return unref(isShow) && Object.keys(_ctx.$slots).includes("default") ? (openBlock(), createElementBlock("section", mergeProps({
        key: 0,
        id: "RoseLayoutFooter"
      }, _ctx.$attrs, {
        ref_key: "footer",
        ref: footer,
        style: [{ "position": "relative", "user-select": "none" }, [
          { background: unref(bg), color: unref(color2), boxShadow: unref(boxShadow), zIndex: unref(zIndex) },
          { paddingTop: `${unref(py)}rem`, paddingBottom: `${unref(py)}rem`, paddingLeft: `${unref(px2)}rem`, paddingRight: `${unref(px2)}rem` }
        ]]
      }), [
        renderSlot(_ctx.$slots, "default"),
        unref(showCard) ? (openBlock(), createElementBlock("div", {
          key: 0,
          ref_key: "card",
          ref: card,
          class: normalizeClass([{ "transition-all duration-200 ease-linear": !unref(isSwiping) }, __props.cardClass]),
          style: normalizeStyle([__props.cardStyle, { background: unref(cardBg) }])
        }, [
          renderSlot(_ctx.$slots, "card")
        ], 6)) : createCommentVNode("v-if", true)
      ], 16)) : createCommentVNode("v-if", true);
    };
  }
});
var __unplugin_components_6 = /* @__PURE__ */ _export_sfc(_sfc_main$b, [["__file", "E:/RoseWeb/rose-admin/src/components/packages/Layout/src/Footer/RoseLayoutFooter.vue"]]);
const _sfc_main$a = {};
const _hoisted_1$3 = { style: { "flex": "1", "display": "flex" } };
function _sfc_render(_ctx, _cache) {
  return openBlock(), createElementBlock("section", _hoisted_1$3, [
    renderSlot(_ctx.$slots, "default")
  ]);
}
var __unplugin_components_5 = /* @__PURE__ */ _export_sfc(_sfc_main$a, [["render", _sfc_render], ["__file", "E:/RoseWeb/rose-admin/src/components/packages/Layout/src/Body/RoseLayoutBody.vue"]]);
const _hoisted_1$2 = ["src"];
const _hoisted_2 = ["src", "controls", "autoplay", "loop", "muted", "preload"];
const _hoisted_3 = /* @__PURE__ */ createTextVNode(" \u60A8\u7684\u6D4F\u89C8\u5668\u4E0D\u652F\u6301 video \u6807\u7B7E\uFF0C\u8BF7\u66F4\u6362\u6D4F\u89C8\u5668\u67E5\u770B ");
const __default__$5 = {
  inheritAttrs: false
};
const _sfc_main$9 = /* @__PURE__ */ defineComponent({
  ...__default__$5,
  __name: "RoseBg",
  props: {
    width: { type: [Number, String, null], required: false, default: "100%" },
    height: { type: [Number, String, null], required: false, default: "100%" },
    top: { type: [Number, String, null], required: false, default: 0 },
    bottom: { type: [Number, String, null], required: false, default: 0 },
    left: { type: [Number, String, null], required: false, default: 0 },
    right: { type: [Number, String, null], required: false, default: 0 },
    opacity: { type: [Number, null], required: false },
    img: { type: [String, null], required: false },
    video: { type: [String, null], required: false },
    controls: { type: null, required: false },
    autoplay: { type: null, required: false, default: "autoplay" },
    loop: { type: null, required: false, default: "loop" },
    muted: { type: null, required: false, default: "muted" },
    preload: { type: null, required: false, default: "auto" },
    fit: { type: null, required: false, default: "cover" }
  },
  setup(__props) {
    useSlots();
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock(Fragment, null, [
        createCommentVNode(" \u80CC\u666F\u663E\u793A\u533A\u57DF\uFF0C\u65B0\u6DFB\u52A0\uFF0C\u76EE\u524D\u53EA\u5728\u5E95\u90E8\u663E\u793A "),
        createElementVNode("div", mergeProps(_ctx.$attrs, {
          style: [{ "position": "absolute", "overflow": "hidden", "display": "flex", "align-items": "flex-end" }, {
            opacity: __props.opacity,
            top: isNaN(Number(__props.top)) ? __props.top : `${__props.top}px`,
            bottom: isNaN(Number(__props.bottom)) ? __props.bottom : `${__props.bottom}px`,
            left: isNaN(Number(__props.left)) ? __props.left : `${__props.left}px`,
            right: isNaN(Number(__props.right)) ? __props.right : `${__props.right}px`
          }]
        }), [
          __props.img ? (openBlock(), createElementBlock("img", {
            key: 0,
            src: __props.img,
            alt: "",
            style: normalizeStyle({
              objectFit: __props.fit,
              width: isNaN(Number(__props.width)) ? __props.width : __props.width.toString().includes("%") ? __props.width : `${__props.width}px`,
              height: isNaN(Number(__props.height)) ? __props.height : __props.height === "100%" ? __props.height : `${__props.height}px`
            })
          }, null, 12, _hoisted_1$2)) : !__props.img && __props.video ? (openBlock(), createElementBlock("video", {
            key: 1,
            src: __props.video,
            style: normalizeStyle({
              objectFit: __props.fit,
              width: isNaN(Number(__props.width)) ? __props.width : __props.width.toString().includes("%") ? __props.width : `${__props.width}px`,
              height: isNaN(Number(__props.height)) ? __props.height : __props.height === "100%" ? __props.height : `${__props.height}px`
            }),
            controls: __props.controls,
            autoplay: __props.autoplay,
            loop: __props.loop,
            muted: __props.muted,
            preload: __props.preload
          }, [
            renderSlot(_ctx.$slots, "default", {}, () => [
              _hoisted_3
            ])
          ], 12, _hoisted_2)) : createCommentVNode("v-if", true)
        ], 16)
      ], 2112);
    };
  }
});
var __unplugin_components_0$1 = /* @__PURE__ */ _export_sfc(_sfc_main$9, [["__file", "E:/RoseWeb/rose-admin/src/components/ui/Bg/RoseBg.vue"]]);
const __default__$4 = {
  inheritAttrs: false
};
const _sfc_main$8 = /* @__PURE__ */ defineComponent({
  ...__default__$4,
  __name: "RoseLayoutRight",
  props: {
    cardWidth: { type: Number, required: false },
    cover: { type: Boolean, required: false, default: true },
    threshold: { type: Number, required: false, default: 15 },
    cardStyle: { type: null, required: false },
    cardClass: { type: [Array, Object], required: false }
  },
  setup(__props, { expose }) {
    const props = __props;
    const solts = useSlots();
    const showCard = computed(() => {
      return solts.card && config.value.Right.showCard;
    });
    const outer = ref(null);
    const RectOuter = useElementBounding(outer);
    const { width, height } = useWindowSize();
    const aside = ref(null);
    const Rect = useElementBounding(aside);
    const card = ref(null);
    const { width: cardW, height: cardH } = useElementBounding(card);
    const { motionProperties: cardProp } = useMotionProperties(card);
    const cardIndex = config.value.ZIndex;
    const isZero = ref(true);
    cardProp.zIndex = cardIndex.down;
    cardProp.opacity = 0;
    cardProp.left = 0;
    cardProp.top = 0;
    cardProp.bottom = 0;
    cardProp.position = "absolute";
    cardProp.width = computedAsync(async () => {
      if (props.cardWidth) {
        return props.cardWidth;
      } else {
        return props.cover ? width.value : width.value - Rect.width.value;
      }
    }, null);
    const onZeroTRUE = () => {
      cardProp.zIndex = cardIndex.down;
      cardProp.opacity = 0;
      cardProp.x = 0;
      cardProp.userSelect = "none";
      cardProp.pointerEvents = "none";
    };
    const onZeroFALSE = () => {
      cardProp.zIndex = cardIndex.up;
      cardProp.opacity = 1;
      cardProp.x = props.cover ? -(cardW.value - Rect.width.value) : -cardW.value;
      cardProp.userSelect = null;
      cardProp.pointerEvents = null;
    };
    const { distanceX, isSwiping } = usePointerSwipe(aside, {
      threshold: props.threshold,
      onSwipeStart(e) {
        if (!showCard.value)
          return;
        isZero.value = cardProp.x ? false : true;
      },
      onSwipe(e) {
        if (!showCard.value)
          return;
        if (distanceX.value < 0) {
          if (!isZero.value) {
            cardProp.zIndex = cardIndex.up;
            cardProp.x = props.cover ? -distanceX.value - (cardW.value - Rect.width.value) : -distanceX.value - cardW.value;
            cardProp.opacity = 1.25 - distanceX.value / cardW.value;
          }
        } else {
          if (isZero.value) {
            cardProp.zIndex = cardIndex.up;
            cardProp.x = -distanceX.value;
            cardProp.opacity = Math.abs(distanceX.value) / cardW.value;
          }
        }
      },
      onSwipeEnd(e, direction) {
        if (!showCard.value)
          return;
        if (direction === "RIGHT" && width.value && !isZero.value && Math.abs(distanceX.value) / width.value >= 0.2) {
          isZero.value = true;
          onZeroTRUE();
        } else if (direction === "LEFT" && width.value && isZero.value && Math.abs(distanceX.value) / width.value >= 0.2) {
          isZero.value = false;
          onZeroFALSE();
        } else {
          if (isZero.value) {
            onZeroTRUE();
          } else {
            onZeroFALSE();
          }
        }
      }
    });
    watch([Rect.width, Rect.height, isZero], ([newasideW, newasideH, newisZero]) => {
      config.value.Right.width = newasideW;
      config.value.Right.height = newasideH;
      config.value.Right.isZero = newisZero;
    });
    const isShow = computed(() => config.value.Right.show);
    const color2 = computed(() => config.value.Right.color);
    const bg = computed(() => config.value.Right.bg);
    const cardBg = computed(() => config.value.Right.cardBg);
    const zIndex = config.value.Right.zIndex;
    const boxShadow = computed(() => config.value.Right.boxShadow);
    const bgImg = computed(() => config.value.Right.bgImg);
    const bgVideo = computed(() => config.value.Right.bgVideo);
    const bgImgOpacity = computed(() => config.value.Right.bgImgOpacity);
    const bgFit = computed(() => config.value.Right.bgFit);
    const py = computed(() => config.value.Right.py);
    const px2 = computed(() => config.value.Right.px);
    useKeyShowHidden(config.value.Right);
    expose({
      cardReset: onZeroTRUE,
      cardOpen: onZeroFALSE
    });
    return (_ctx, _cache) => {
      const _component_RoseBg = __unplugin_components_0$1;
      return unref(isShow) && Object.keys(_ctx.$slots).includes("default") ? (openBlock(), createElementBlock("section", {
        key: 0,
        id: "RoseLayoutRight",
        ref_key: "aside",
        ref: aside,
        style: normalizeStyle([{ "position": "relative", "height": "100%" }, { width: unref(RectOuter).width.value + "px", background: unref(bg), color: unref(color2), boxShadow: unref(boxShadow), zIndex: unref(zIndex) }])
      }, [
        createElementVNode("div", mergeProps({
          ref_key: "outer",
          ref: outer
        }, _ctx.$attrs, {
          style: [[
            { paddingTop: `${unref(py)}rem`, paddingBottom: `${unref(py)}rem`, paddingLeft: `${unref(px2)}rem`, paddingRight: `${unref(px2)}rem` }
          ], { "overflow": "auto", "position": "absolute", "top": "0", "bottom": "0", "right": "0", "user-select": "none" }]
        }), [
          renderSlot(_ctx.$slots, "default")
        ], 16),
        unref(showCard) ? (openBlock(), createElementBlock("div", {
          key: 0,
          ref_key: "card",
          ref: card,
          class: normalizeClass([{ "transition-all duration-200 ease-linear": !unref(isSwiping) }, __props.cardClass]),
          style: normalizeStyle([__props.cardStyle, { background: unref(cardBg) }])
        }, [
          renderSlot(_ctx.$slots, "card")
        ], 6)) : createCommentVNode("v-if", true),
        createCommentVNode(" \u80CC\u666F\u663E\u793A\u533A\u57DF\uFF0C\u65B0\u6DFB\u52A0\uFF0C\u76EE\u524D\u53EA\u5728\u5E95\u90E8\u663E\u793A "),
        createCommentVNode(' <div v-if="bgImg" style="\r\n        position: absolute;\r\n        top: 0;\r\n        bottom: 0;\r\n        left: 0;\r\n        right: 0;\r\n        z-index: -10;\r\n        overflow: hidden;\r\n        display: flex;\r\n        align-items: flex-end;\r\n      " :style="[{ opacity: bgImgOpacity }]">\r\n			<img :src="bgImg" alt="" style="object-fit: cover" />\r\n		</div> '),
        createVNode(_component_RoseBg, {
          img: unref(bgImg),
          video: unref(bgVideo),
          opacity: unref(bgImgOpacity),
          fit: unref(bgFit),
          style: { "z-index": "-10", "pointer-events": "none" }
        }, null, 8, ["img", "video", "opacity", "fit"])
      ], 4)) : createCommentVNode("v-if", true);
    };
  }
});
var __unplugin_components_4 = /* @__PURE__ */ _export_sfc(_sfc_main$8, [["__file", "E:/RoseWeb/rose-admin/src/components/packages/Layout/src/Right/RoseLayoutRight.vue"]]);
const _sfc_main$7 = /* @__PURE__ */ defineComponent({
  __name: "RoseLayoutContentTop",
  setup(__props) {
    const box = ref(null);
    const Rect = useElementBounding(box);
    watch([Rect.width, Rect.height], ([newasideW, newasideH]) => {
      config.value.ContentTop.width = newasideW;
      config.value.ContentTop.height = newasideH;
    });
    const isShow = computed(() => config.value.ContentTop.show);
    const color2 = computed(() => config.value.ContentTop.color);
    const bg = computed(() => config.value.ContentTop.bg);
    const zIndex = config.value.ContentTop.zIndex;
    const boxShadow = computed(() => config.value.ContentTop.boxShadow);
    const py = computed(() => config.value.ContentTop.py);
    const px2 = computed(() => config.value.ContentTop.px);
    useKeyShowHidden(config.value.ContentTop);
    return (_ctx, _cache) => {
      return unref(isShow) && Object.keys(_ctx.$slots).includes("default") ? (openBlock(), createElementBlock("section", mergeProps({
        key: 0,
        id: "RoseLayoutContentTop",
        ref_key: "box",
        ref: box
      }, _ctx.$attrs, {
        style: [
          { background: unref(bg), color: unref(color2), boxShadow: unref(boxShadow), zIndex: unref(zIndex) },
          { paddingTop: `${unref(py)}rem`, paddingBottom: `${unref(py)}rem`, paddingLeft: `${unref(px2)}rem`, paddingRight: `${unref(px2)}rem` }
        ]
      }), [
        renderSlot(_ctx.$slots, "default")
      ], 16)) : createCommentVNode("v-if", true);
    };
  }
});
var RoseLayoutContentTop = /* @__PURE__ */ _export_sfc(_sfc_main$7, [["__file", "E:/RoseWeb/rose-admin/src/components/packages/Layout/src/Content/components/Top/RoseLayoutContentTop.vue"]]);
const _sfc_main$6 = /* @__PURE__ */ defineComponent({
  __name: "RoseLayoutContentBox",
  setup(__props) {
    computed(() => config.value.ContentTop.show);
    const isShow = computed(() => config.value.ContentBox.show);
    const color2 = computed(() => config.value.ContentBox.color);
    const bg = computed(() => config.value.ContentBox.bg);
    const zIndex = config.value.ContentBox.zIndex;
    const boxShadow = computed(() => config.value.ContentBox.boxShadow);
    const py = computed(() => config.value.ContentBox.py);
    const px2 = computed(() => config.value.ContentBox.px);
    const pt = computed(() => config.value.ContentBox.pt);
    const pb = computed(() => config.value.ContentBox.pb);
    const pl = computed(() => config.value.ContentBox.pl);
    const pr = computed(() => config.value.ContentBox.pr);
    useKeyShowHidden(config.value.ContentBox);
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock(Fragment, null, [
        createCommentVNode(" !isTopShow ? { width: '100%', height: '100%' } : '', "),
        unref(isShow) && Object.keys(_ctx.$slots).includes("default") ? (openBlock(), createElementBlock("section", mergeProps({
          key: 0,
          id: "RoseLayoutContentBoxIn",
          ref: "box"
        }, _ctx.$attrs, {
          style: [
            { width: "100%", height: "100%", boxSizing: "border-box" },
            { background: unref(bg), color: unref(color2), boxShadow: unref(boxShadow), zIndex: unref(zIndex), flex: 1 },
            { paddingTop: `${unref(pt) || unref(py)}rem`, paddingBottom: `${unref(pb) || unref(py)}rem`, paddingLeft: `${unref(pl) || unref(px2)}rem`, paddingRight: `${unref(pr) || unref(px2)}rem` }
          ]
        }), [
          renderSlot(_ctx.$slots, "default")
        ], 16)) : createCommentVNode("v-if", true)
      ], 2112);
    };
  }
});
var RoseLayoutContentBox = /* @__PURE__ */ _export_sfc(_sfc_main$6, [["__file", "E:/RoseWeb/rose-admin/src/components/packages/Layout/src/Content/components/Box/RoseLayoutContentBox.vue"]]);
const _sfc_main$5 = /* @__PURE__ */ defineComponent({
  __name: "RoseLayoutContentBottom",
  setup(__props) {
    const box = ref(null);
    const Rect = useElementBounding(box);
    watch([Rect.width, Rect.height], ([newasideW, newasideH]) => {
      config.value.ContentBottom.width = newasideW;
      config.value.ContentBottom.height = newasideH;
    });
    const isShow = computed(() => config.value.ContentBottom.show);
    const color2 = computed(() => config.value.ContentBottom.color);
    const bg = computed(() => config.value.ContentBottom.bg);
    const zIndex = config.value.ContentBottom.zIndex;
    const boxShadow = computed(() => config.value.ContentBottom.boxShadow);
    const py = computed(() => config.value.ContentBottom.py);
    const px2 = computed(() => config.value.ContentBottom.px);
    useKeyShowHidden(config.value.ContentBottom);
    return (_ctx, _cache) => {
      return unref(isShow) && Object.keys(_ctx.$slots).includes("default") ? (openBlock(), createElementBlock("section", mergeProps({
        key: 0,
        id: "RoseLayoutContentBottom",
        ref_key: "box",
        ref: box
      }, _ctx.$attrs, {
        style: [
          { background: unref(bg), color: unref(color2), boxShadow: unref(boxShadow), zIndex: unref(zIndex) },
          { paddingTop: `${unref(py)}rem`, paddingBottom: `${unref(py)}rem`, paddingLeft: `${unref(px2)}rem`, paddingRight: `${unref(px2)}rem` }
        ]
      }), [
        renderSlot(_ctx.$slots, "default")
      ], 16)) : createCommentVNode("v-if", true);
    };
  }
});
var RoseLayoutContentBottom = /* @__PURE__ */ _export_sfc(_sfc_main$5, [["__file", "E:/RoseWeb/rose-admin/src/components/packages/Layout/src/Content/components/Bottom/RoseLayoutContentBottom.vue"]]);
const _hoisted_1$1 = {
  key: 1,
  ref: "refRoseLayoutContentBox",
  id: "RoseLayoutContentBox",
  style: { "flex": "1", "position": "relative", "height": "100%" }
};
const _sfc_main$4 = /* @__PURE__ */ defineComponent({
  __name: "RoseLayoutContent",
  setup(__props) {
    const color2 = computed(() => config.value.Content.color);
    const bg = computed(() => config.value.Content.bg);
    const isShow = computed(() => config.value.Content.show);
    const zIndex = config.value.Content.zIndex;
    const boxShadow = computed(() => config.value.Content.boxShadow);
    const py = computed(() => config.value.Content.py);
    const px2 = computed(() => config.value.Content.px);
    const pt = computed(() => config.value.Content.pt);
    const pb = computed(() => config.value.Content.pb);
    const pl = computed(() => config.value.Content.pl);
    const pr = computed(() => config.value.Content.pr);
    const pointerEvents = computed(() => config.value.Content.pointerEvents);
    const isOverflow = computed(() => config.value.ContentBox.overflow);
    useKeyShowHidden(config.value.Content);
    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("section", {
        id: "RoseLayoutContent",
        style: normalizeStyle([
          { "flex": "1", "display": "flex", "flex-direction": "column", "justify-content": "stretch" },
          {
            paddingTop: `${unref(pt) || unref(py)}rem`,
            paddingBottom: `${unref(pb) || unref(py)}rem`,
            paddingLeft: `${unref(pl) || unref(px2)}rem`,
            paddingRight: `${unref(pr) || unref(px2)}rem`,
            boxShadow: unref(boxShadow),
            zIndex: unref(zIndex),
            background: unref(bg),
            color: unref(color2),
            pointerEvents: unref(pointerEvents) ? "none" : "",
            position: "relative"
          }
        ])
      }, [
        Object.keys(_ctx.$slots).includes("contentTop") ? (openBlock(), createBlock(RoseLayoutContentTop, { key: 0 }, {
          default: withCtx(() => [
            renderSlot(_ctx.$slots, "contentTop")
          ]),
          _: 3
        })) : createCommentVNode("v-if", true),
        unref(isShow) ? (openBlock(), createElementBlock("section", _hoisted_1$1, [
          createElementVNode("div", {
            id: "RoseLayoutContentBoxScroll",
            style: normalizeStyle([{ overflow: unref(isOverflow) ? "auto" : "" }, { "position": "absolute", "top": "0", "bottom": "0", "left": "0", "right": "0", "display": "flex" }])
          }, [
            createCommentVNode(` <RoseLayoutContentTop v-if="Object.keys($slots).includes('contentTop')">\r
					<slot name="contentTop" />\r
				</RoseLayoutContentTop>`),
            Object.keys(_ctx.$slots).includes("contentBox") ? (openBlock(), createBlock(RoseLayoutContentBox, { key: 0 }, {
              default: withCtx(() => [
                renderSlot(_ctx.$slots, "contentBox")
              ]),
              _: 3
            })) : createCommentVNode("v-if", true),
            renderSlot(_ctx.$slots, "default")
          ], 4)
        ], 512)) : createCommentVNode("v-if", true),
        unref(isShow) && Object.keys(_ctx.$slots).includes("contentBottom") ? (openBlock(), createBlock(RoseLayoutContentBottom, { key: 2 }, {
          default: withCtx(() => [
            renderSlot(_ctx.$slots, "contentBottom")
          ]),
          _: 3
        })) : createCommentVNode("v-if", true)
      ], 4);
    };
  }
});
var __unplugin_components_3 = /* @__PURE__ */ _export_sfc(_sfc_main$4, [["__file", "E:/RoseWeb/rose-admin/src/components/packages/Layout/src/Content/RoseLayoutContent.vue"]]);
const __default__$3 = {
  inheritAttrs: false
};
const _sfc_main$3 = /* @__PURE__ */ defineComponent({
  ...__default__$3,
  __name: "RoseLayoutLeft",
  props: {
    cardWidth: { type: Number, required: false },
    cover: { type: Boolean, required: false, default: true },
    threshold: { type: Number, required: false, default: 15 },
    cardStyle: { type: null, required: false },
    cardClass: { type: [Array, Object], required: false }
  },
  setup(__props, { expose }) {
    const props = __props;
    const solts = useSlots();
    const showCard = computed(() => {
      return solts.card && config.value.Left.showCard;
    });
    const outer = ref(null);
    const RectOuter = useElementBounding(outer);
    const { width, height } = useWindowSize();
    const aside = ref(null);
    const Rect = useElementBounding(aside);
    const card = ref(null);
    const { width: cardW, height: cardH } = useElementBounding(card);
    const { motionProperties: cardProp } = useMotionProperties(card);
    const cardIndex = config.value.ZIndex;
    const isZero = ref(true);
    cardProp.zIndex = cardIndex.down;
    cardProp.opacity = 0;
    cardProp.right = 0;
    cardProp.top = 0;
    cardProp.bottom = 0;
    cardProp.position = "absolute";
    cardProp.width = computedAsync(async () => {
      if (props.cardWidth) {
        return props.cardWidth;
      } else {
        return props.cover ? width.value : width.value - Rect.width.value;
      }
    }, null);
    const onZeroTRUE = () => {
      cardProp.zIndex = cardIndex.down;
      cardProp.opacity = 0;
      cardProp.x = 0;
    };
    const onZeroFALSE = () => {
      cardProp.zIndex = cardIndex.up;
      cardProp.opacity = 1;
      cardProp.x = props.cover ? cardW.value - Rect.width.value : cardW.value;
    };
    const { distanceX, isSwiping } = usePointerSwipe(aside, {
      threshold: props.threshold,
      onSwipeStart(e) {
        if (!showCard.value)
          return;
        isZero.value = cardProp.x ? false : true;
      },
      onSwipe(e) {
        if (!showCard.value)
          return;
        if (distanceX.value < 0) {
          if (isZero.value) {
            cardProp.zIndex = cardIndex.up;
            cardProp.x = -distanceX.value;
            cardProp.opacity = Math.abs(distanceX.value) / cardW.value;
          }
        } else {
          if (!isZero.value) {
            cardProp.zIndex = cardIndex.up;
            cardProp.x = props.cover ? cardW.value - Rect.width.value - distanceX.value : cardW.value - distanceX.value;
            cardProp.opacity = 1.25 - distanceX.value / cardW.value;
          }
        }
      },
      onSwipeEnd(e, direction) {
        if (!showCard.value)
          return;
        if (direction === "RIGHT" && height.value && isZero.value && Math.abs(distanceX.value) / height.value >= 0.2) {
          isZero.value = false;
          onZeroFALSE();
        } else if (direction === "LEFT" && height.value && !isZero.value && distanceX.value / height.value >= 0.2) {
          isZero.value = true;
          onZeroTRUE();
        } else {
          if (isZero.value) {
            onZeroTRUE();
          } else {
            onZeroFALSE();
          }
        }
      }
    });
    watch([Rect.width, Rect.height, isZero], ([newasideW, newasideH, newisZero]) => {
      config.value.Left.width = newasideW;
      config.value.Left.height = newasideH;
      config.value.Left.isZero = newisZero;
    });
    const isShow = computed(() => config.value.Left.show);
    const color2 = computed(() => config.value.Left.color);
    const bg = computed(() => config.value.Left.bg);
    const cardBg = computed(() => config.value.Left.cardBg);
    const zIndex = config.value.Left.zIndex;
    const boxShadow = computed(() => config.value.Left.boxShadow);
    const bgImg = computed(() => config.value.Left.bgImg);
    const bgVideo = computed(() => config.value.Left.bgVideo);
    const bgImgOpacity = computed(() => config.value.Left.bgImgOpacity);
    const bgFit = computed(() => config.value.Left.bgFit);
    const py = computed(() => config.value.Left.py);
    const px2 = computed(() => config.value.Left.px);
    useKeyShowHidden(config.value.Left);
    expose({
      cardReset: onZeroTRUE,
      cardOpen: onZeroFALSE
    });
    return (_ctx, _cache) => {
      const _component_RoseBg = __unplugin_components_0$1;
      return unref(isShow) && Object.keys(_ctx.$slots).includes("default") ? (openBlock(), createElementBlock("section", {
        key: 0,
        id: "RoseLayoutLeft",
        ref_key: "aside",
        ref: aside,
        style: normalizeStyle([{ "position": "relative", "height": "100%", "display": "inline-table" }, { width: unref(RectOuter).width.value + "px", background: unref(bg), color: unref(color2), boxShadow: unref(boxShadow), zIndex: unref(zIndex) }])
      }, [
        createElementVNode("div", mergeProps({
          ref_key: "outer",
          ref: outer
        }, _ctx.$attrs, {
          style: [[
            { paddingTop: `${unref(py)}rem`, paddingBottom: `${unref(py)}rem`, paddingLeft: `${unref(px2)}rem`, paddingRight: `${unref(px2)}rem` }
          ], { "overflow": "auto", "position": "absolute", "top": "0", "bottom": "0", "left": "0", "user-select": "none" }]
        }), [
          renderSlot(_ctx.$slots, "default")
        ], 16),
        unref(showCard) ? (openBlock(), createElementBlock("div", {
          key: 0,
          ref_key: "card",
          ref: card,
          class: normalizeClass([{ "transition-all duration-200 ease-linear": !unref(isSwiping) }, __props.cardClass]),
          style: normalizeStyle([__props.cardStyle, { background: unref(cardBg) }])
        }, [
          renderSlot(_ctx.$slots, "card")
        ], 6)) : createCommentVNode("v-if", true),
        createCommentVNode(" \u80CC\u666F\u663E\u793A\u533A\u57DF\uFF0C\u65B0\u6DFB\u52A0\uFF0C\u76EE\u524D\u53EA\u5728\u5E95\u90E8\u663E\u793A "),
        createCommentVNode(' <div v-if="bgImg" style="\r\n        position: absolute;\r\n        top: 0;\r\n        bottom: 0;\r\n        left: 0;\r\n        right: 0;\r\n        z-index: -10;\r\n        overflow: hidden;\r\n        display: flex;\r\n        align-items: flex-end;\r\n      " :style="[{ opacity: bgImgOpacity }]">\r\n			<img :src="bgImg" alt="" style="object-fit: cover" />\r\n		</div> '),
        createVNode(_component_RoseBg, {
          img: unref(bgImg),
          video: unref(bgVideo),
          opacity: unref(bgImgOpacity),
          fit: unref(bgFit),
          style: { "z-index": "-10", "pointer-events": "none" }
        }, null, 8, ["img", "video", "opacity", "fit"])
      ], 4)) : createCommentVNode("v-if", true);
    };
  }
});
var __unplugin_components_2 = /* @__PURE__ */ _export_sfc(_sfc_main$3, [["__file", "E:/RoseWeb/rose-admin/src/components/packages/Layout/src/Left/RoseLayoutLeft.vue"]]);
const __default__$2 = {
  inheritAttrs: false
};
const _sfc_main$2 = /* @__PURE__ */ defineComponent({
  ...__default__$2,
  __name: "RoseLayoutHeader",
  props: {
    cardHeight: { type: Number, required: false },
    cover: { type: Boolean, required: false, default: true },
    threshold: { type: Number, required: false, default: 15 },
    cardStyle: { type: null, required: false },
    cardClass: { type: [Array, Object], required: false }
  },
  setup(__props, { expose }) {
    const props = __props;
    const solts = useSlots();
    const showCard = computed(() => {
      return solts.card && config.value.Header.showCard;
    });
    const { width, height } = useWindowSize();
    const header = ref(null);
    const Rect = useElementBounding(header);
    const card = ref(null);
    const { width: cardW, height: cardH } = useElementBounding(card);
    const { motionProperties: cardProp } = useMotionProperties(card);
    const cardIndex = config.value.ZIndex;
    const isZero = ref(true);
    cardProp.zIndex = cardIndex.down;
    cardProp.opacity = 0;
    cardProp.bottom = 0;
    cardProp.left = 0;
    cardProp.right = 0;
    cardProp.position = "absolute";
    cardProp.height = computedAsync(async () => {
      if (props.cardHeight) {
        return props.cardHeight;
      } else {
        return props.cover ? height.value : height.value - Rect.height.value;
      }
    }, null);
    const onZeroTRUE = () => {
      cardProp.zIndex = cardIndex.down;
      cardProp.opacity = 0;
      cardProp.y = 0;
    };
    const onZeroFALSE = () => {
      cardProp.zIndex = cardIndex.up;
      cardProp.opacity = 1;
      cardProp.y = props.cover ? cardH.value - Rect.height.value : cardH.value;
    };
    const { distanceY, isSwiping, stop } = usePointerSwipe(header, {
      threshold: props.threshold,
      onSwipeStart(e) {
        if (!showCard.value)
          return;
        isZero.value = cardProp.y ? false : true;
      },
      onSwipe(e) {
        if (!showCard.value)
          return;
        if (distanceY.value < 0) {
          if (isZero.value) {
            cardProp.zIndex = cardIndex.up;
            cardProp.y = -distanceY.value;
            cardProp.opacity = Math.abs(distanceY.value) / cardH.value;
          }
        } else {
          if (!isZero.value) {
            cardProp.zIndex = cardIndex.up;
            cardProp.y = props.cover ? cardH.value - Rect.height.value - distanceY.value : cardH.value - distanceY.value;
            cardProp.opacity = 1.25 - distanceY.value / cardH.value;
          }
        }
      },
      onSwipeEnd(e, direction) {
        if (!showCard.value)
          return;
        if (direction === "DOWN" && height.value && isZero.value && Math.abs(distanceY.value) / height.value >= 0.2) {
          isZero.value = false;
          onZeroFALSE();
        } else if (direction === "UP" && height.value && !isZero.value && distanceY.value / height.value >= 0.2) {
          isZero.value = true;
          onZeroTRUE();
        } else {
          if (isZero.value) {
            onZeroTRUE();
          } else {
            onZeroFALSE();
          }
        }
      }
    });
    watch(
      [Rect.width, Rect.height, isZero],
      ([newheaderW, newheaderH, newisZero], [prevheaderW, prevheaderH, preisZero]) => {
        config.value.Header.width = newheaderW;
        config.value.Header.height = newheaderH;
        config.value.Header.isZero = newisZero;
      }
    );
    const isShow = computed(() => config.value.Header.show);
    const color2 = computed(() => config.value.Header.color);
    const bg = computed(() => config.value.Header.bg);
    const cardBg = computed(() => config.value.Header.cardBg);
    const zIndex = config.value.Header.zIndex;
    const boxShadow = computed(() => config.value.Header.boxShadow);
    const bgImg = computed(() => config.value.Header.bgImg);
    const bgVideo = computed(() => config.value.Header.bgVideo);
    const bgImgOpacity = computed(() => config.value.Header.bgImgOpacity);
    const bgFit = computed(() => config.value.Header.bgFit);
    const py = computed(() => config.value.Header.py);
    const px2 = computed(() => config.value.Header.px);
    useKeyShowHidden(config.value.Header);
    expose({
      cardReset: onZeroTRUE,
      cardOpen: onZeroFALSE
    });
    return (_ctx, _cache) => {
      const _component_RoseBg = __unplugin_components_0$1;
      return unref(isShow) && Object.keys(_ctx.$slots).includes("default") ? (openBlock(), createElementBlock("header", mergeProps({
        key: 0,
        id: "RoseLayoutHeader"
      }, _ctx.$attrs, {
        ref_key: "header",
        ref: header,
        style: [{ "position": "relative", "user-select": "none" }, [
          { background: unref(bg), color: unref(color2), boxShadow: unref(boxShadow), zIndex: unref(zIndex) },
          { paddingTop: `${unref(py)}rem`, paddingBottom: `${unref(py)}rem`, paddingLeft: `${unref(px2)}rem`, paddingRight: `${unref(px2)}rem` }
        ]]
      }), [
        renderSlot(_ctx.$slots, "default"),
        createCommentVNode(` <div v-if="Object.keys($slots).includes('card')" ref="card" :class="[{ 'transition-all duration-200 ease-linear': !isSwiping },cardClass]" :style="cardStyle"> `),
        unref(showCard) ? (openBlock(), createElementBlock("div", {
          key: 0,
          ref_key: "card",
          ref: card,
          class: normalizeClass([{ "transition-all duration-200 ease-linear": !unref(isSwiping) }, __props.cardClass]),
          style: normalizeStyle([__props.cardStyle, { background: unref(cardBg) }])
        }, [
          renderSlot(_ctx.$slots, "card")
        ], 6)) : createCommentVNode("v-if", true),
        createCommentVNode(" \u80CC\u666F\u663E\u793A\u533A\u57DF\uFF0C\u65B0\u6DFB\u52A0\uFF0C\u76EE\u524D\u53EA\u5728\u53F3\u4FA7\u663E\u793A "),
        createCommentVNode(' <div v-if="bgImg" style="\r\n        position: absolute;\r\n        top: 0;\r\n        bottom: 0;\r\n        left: 0;\r\n        right: 0;\r\n        z-index: -10;\r\n        overflow: hidden;\r\n        display: flex;\r\n        justify-content: flex-end;\r\n      " :style="[{ opacity: bgImgOpacity }]">\r\n			<img :src="bgImg" alt="" style="object-fit: cover" />\r\n		</div> '),
        createVNode(_component_RoseBg, {
          img: unref(bgImg),
          video: unref(bgVideo),
          opacity: unref(bgImgOpacity),
          fit: unref(bgFit),
          style: { "z-index": "-10", "pointer-events": "none" }
        }, null, 8, ["img", "video", "opacity", "fit"])
      ], 16)) : createCommentVNode("v-if", true);
    };
  }
});
var __unplugin_components_1 = /* @__PURE__ */ _export_sfc(_sfc_main$2, [["__file", "E:/RoseWeb/rose-admin/src/components/packages/Layout/src/Header/RoseLayoutHeader.vue"]]);
const __default__$1 = {
  inheritAttrs: false
};
const _sfc_main$1 = /* @__PURE__ */ defineComponent({
  ...__default__$1,
  __name: "RoseLayoutBg",
  setup(__props) {
    const isShow = computed(() => config.value.Bg.show);
    const bg = computed(() => config.value.Bg.bg);
    const color2 = computed(() => config.value.Bg.color);
    const zIndex = config.value.Bg.zIndex;
    const py = computed(() => config.value.Bg.py);
    const px2 = computed(() => config.value.Bg.px);
    const bgImg = computed(() => config.value.Bg.bgImg);
    const bgVideo = computed(() => config.value.Bg.bgVideo);
    const bgImgOpacity = computed(() => config.value.Bg.bgImgOpacity);
    const bgFit = computed(() => config.value.Bg.bgFit);
    useKeyShowHidden(config.value.Bg);
    return (_ctx, _cache) => {
      const _component_RoseBg = __unplugin_components_0$1;
      return unref(isShow) && Object.keys(_ctx.$slots).includes("default") ? (openBlock(), createElementBlock("section", {
        key: 0,
        id: "RoseLayoutBg",
        style: normalizeStyle([{ "position": "absolute", "top": "0", "left": "0", "bottom": "0", "right": "0", "zIndex": "-10" }, [
          { background: unref(bg), color: unref(color2), zIndex: unref(zIndex) },
          { paddingTop: `${unref(py)}rem`, paddingBottom: `${unref(py)}rem`, paddingLeft: `${unref(px2)}rem`, paddingRight: `${unref(px2)}rem` }
        ]])
      }, [
        createVNode(_component_RoseBg, {
          img: unref(bgImg),
          video: unref(bgVideo),
          opacity: unref(bgImgOpacity),
          fit: unref(bgFit),
          style: { "pointer-events": "none" }
        }, null, 8, ["img", "video", "opacity", "fit"]),
        renderSlot(_ctx.$slots, "default")
      ], 4)) : createCommentVNode("v-if", true);
    };
  }
});
var __unplugin_components_0 = /* @__PURE__ */ _export_sfc(_sfc_main$1, [["__file", "E:/RoseWeb/rose-admin/src/components/packages/Layout/src/Bg/RoseLayoutBg.vue"]]);
const _hoisted_1 = {
  class: "yst h-screen w-full relative",
  style: { "overflow": "hidden" }
};
const __default__ = {
  name: "RoseLayout"
};
const _sfc_main = /* @__PURE__ */ defineComponent({
  ...__default__,
  setup(__props) {
    const slot = useSlots();
    return (_ctx, _cache) => {
      const _component_RoseLayoutBg = __unplugin_components_0;
      const _component_RoseLayoutHeader = __unplugin_components_1;
      const _component_RoseLayoutLeft = __unplugin_components_2;
      const _component_RoseLayoutContent = __unplugin_components_3;
      const _component_RoseLayoutRight = __unplugin_components_4;
      const _component_RoseLayoutBody = __unplugin_components_5;
      const _component_RoseLayoutFooter = __unplugin_components_6;
      return openBlock(), createElementBlock("div", _hoisted_1, [
        createCommentVNode(" <RoseLayoutSetting /> "),
        unref(slot).bg ? (openBlock(), createBlock(_component_RoseLayoutBg, { key: 0 }, {
          default: withCtx(() => [
            renderSlot(_ctx.$slots, "bg")
          ]),
          _: 3
        })) : createCommentVNode("v-if", true),
        unref(slot).header ? (openBlock(), createBlock(_component_RoseLayoutHeader, { key: 1 }, createSlots({
          default: withCtx(() => [
            renderSlot(_ctx.$slots, "header")
          ]),
          _: 2
        }, [
          unref(slot).headerCard ? {
            name: "card",
            fn: withCtx(() => [
              renderSlot(_ctx.$slots, "headerCard")
            ])
          } : void 0
        ]), 1024)) : createCommentVNode("v-if", true),
        createVNode(_component_RoseLayoutBody, null, {
          default: withCtx(() => [
            createCommentVNode(' <section class="flex-1 xlt"> '),
            unref(slot).left ? (openBlock(), createBlock(_component_RoseLayoutLeft, { key: 0 }, createSlots({
              default: withCtx(() => [
                renderSlot(_ctx.$slots, "left")
              ]),
              _: 2
            }, [
              unref(slot).leftCard ? {
                name: "card",
                fn: withCtx(() => [
                  renderSlot(_ctx.$slots, "leftCard")
                ])
              } : void 0
            ]), 1024)) : createCommentVNode("v-if", true),
            unref(slot).contentTop || unref(slot).contentBox || unref(slot).contentBottom || unref(slot).default ? (openBlock(), createBlock(_component_RoseLayoutContent, { key: 1 }, createSlots({
              default: withCtx(() => [
                unref(slot).default ? renderSlot(_ctx.$slots, "default", { key: 0 }) : createCommentVNode("v-if", true)
              ]),
              _: 2
            }, [
              unref(slot).contentTop ? {
                name: "contentTop",
                fn: withCtx(() => [
                  renderSlot(_ctx.$slots, "contentTop")
                ])
              } : void 0,
              unref(slot).contentBox ? {
                name: "contentBox",
                fn: withCtx(() => [
                  renderSlot(_ctx.$slots, "contentBox")
                ])
              } : void 0,
              unref(slot).contentBottom ? {
                name: "contentBottom",
                fn: withCtx(() => [
                  renderSlot(_ctx.$slots, "contentBottom")
                ])
              } : void 0
            ]), 1024)) : createCommentVNode("v-if", true),
            unref(slot).right ? (openBlock(), createBlock(_component_RoseLayoutRight, { key: 2 }, createSlots({
              default: withCtx(() => [
                renderSlot(_ctx.$slots, "right")
              ]),
              _: 2
            }, [
              unref(slot).rightCard ? {
                name: "card",
                fn: withCtx(() => [
                  renderSlot(_ctx.$slots, "rightCard")
                ])
              } : void 0
            ]), 1024)) : createCommentVNode("v-if", true),
            createCommentVNode(" </section> ")
          ]),
          _: 3
        }),
        createCommentVNode(' <section class="bg-cyan-300">footer</section> '),
        unref(slot).footer ? (openBlock(), createBlock(_component_RoseLayoutFooter, { key: 2 }, createSlots({
          default: withCtx(() => [
            renderSlot(_ctx.$slots, "footer")
          ]),
          _: 2
        }, [
          unref(slot).footerCard ? {
            name: "card",
            fn: withCtx(() => [
              renderSlot(_ctx.$slots, "footerCard")
            ])
          } : void 0
        ]), 1024)) : createCommentVNode("v-if", true)
      ]);
    };
  }
});
var RoseLayout = /* @__PURE__ */ _export_sfc(_sfc_main, [["__file", "E:/RoseWeb/rose-admin/src/components/packages/Layout/src/RoseLayout.vue"]]);
const components = [RoseLayout];
const install = function(app, options) {
  components.forEach((component) => {
    app.component(component.name, component);
  });
};
var _export = {
  version: "0.0.1",
  install
};
export { _export as default, useConfigLayout, useKeyConfigLayout, useKeyLayout, useKeyShowHidden };
